@@ -19,7 +19,8 @@ from .const import (
     SENSOR_STATUS_RSSI,
     SENSOR_STATUS_SIGNAL,
     SENSOR_STATUS_SSID,
-    SIGNAL_STRENGTH_DECIBELS,
+    SENSOR_STATUS_VERSION,
+    SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
 )
 from .entity import (
     TasmotaAvailability,
@@ -64,6 +65,7 @@ SENSORS = [
     SENSOR_STATUS_RSSI,
     SENSOR_STATUS_SIGNAL,
     SENSOR_STATUS_SSID,
+    SENSOR_STATUS_VERSION,
 ]
 
 NAMES = {
@@ -75,9 +77,14 @@ NAMES = {
     SENSOR_STATUS_RSSI: "RSSI",
     SENSOR_STATUS_SIGNAL: "Signal",
     SENSOR_STATUS_SSID: "SSID",
+    SENSOR_STATUS_VERSION: "Firmware Version",
 }
 
-SINGLE_SHOT = [SENSOR_STATUS_LAST_RESTART_TIME, SENSOR_STATUS_RESTART_REASON]
+SINGLE_SHOT = [
+    SENSOR_STATUS_LAST_RESTART_TIME,
+    SENSOR_STATUS_RESTART_REASON,
+    SENSOR_STATUS_VERSION,
+]
 
 STATE_PATHS = {
     SENSOR_STATUS_LINK_COUNT: ["Wifi", "LinkCount"],
@@ -94,6 +101,7 @@ STATUS_PATHS = {
     SENSOR_STATUS_RSSI: ["StatusSTS", "Wifi", "RSSI"],
     SENSOR_STATUS_SIGNAL: ["StatusSTS", "Wifi", "Signal"],
     SENSOR_STATUS_SSID: ["StatusSTS", "Wifi", "SSId"],
+    SENSOR_STATUS_VERSION: ["StatusFWR", "Version"],
 }
 
 STATUS_TOPICS = {
@@ -104,6 +112,7 @@ STATUS_TOPICS = {
     SENSOR_STATUS_RSSI: 11,
     SENSOR_STATUS_SIGNAL: 11,
     SENSOR_STATUS_SSID: 11,
+    SENSOR_STATUS_VERSION: 2,
 }
 
 QUANTITY = {
@@ -115,6 +124,7 @@ QUANTITY = {
     SENSOR_STATUS_RSSI: SENSOR_STATUS_RSSI,
     SENSOR_STATUS_SIGNAL: SENSOR_STATUS_SIGNAL,
     SENSOR_STATUS_SSID: SENSOR_STATUS_SSID,
+    SENSOR_STATUS_VERSION: SENSOR_STATUS_VERSION,
 }
 
 UNITS = {
@@ -124,8 +134,9 @@ UNITS = {
     SENSOR_STATUS_MQTT_COUNT: None,
     SENSOR_STATUS_RESTART_REASON: None,
     SENSOR_STATUS_RSSI: PERCENTAGE,
-    SENSOR_STATUS_SIGNAL: SIGNAL_STRENGTH_DECIBELS,
+    SENSOR_STATUS_SIGNAL: SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
     SENSOR_STATUS_SSID: None,
+    SENSOR_STATUS_VERSION: None,
 }
 
 
